#
# spec file for package python-opentelemetry-test-utils
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-opentelemetry-test-utils
Version:        0.50b0
Release:        1.1
Summary:        Test utilities for OpenTelemetry unit tests
License:        Apache-2.0
URL:            https://github.com/open-telemetry/opentelemetry-python/
Source:         https://files.pythonhosted.org/packages/source/o/opentelemetry-test-utils/opentelemetry_test_utils-%{version}.tar.gz
BuildRequires:  %{python_module asgiref >= 3.0}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module opentelemetry-api == 1.29.0}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-asgiref
Requires:       python-opentelemetry-api == 1.29.0
BuildArch:      noarch
%python_subpackages

%description
OpenTelemetry Test Utilities

This package provides internal testing utilities for the OpenTelemetry Python
project and provides no stability or quality guarantees.  Please do not use it
for anything other than writing or running tests for the OpenTelemetry Python
project (github.com/open-telemetry/opentelemetry-python).

%prep
%autosetup -p1 -n opentelemetry_test_utils-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%dir %{python_sitelib}/opentelemetry
%{python_sitelib}/opentelemetry/test
%{python_sitelib}/opentelemetry_test_utils-%{version}.dist-info

%changelog
* Wed Jan  8 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.50b0
  * Fix crash exporting a log record with None body
  * Fix metrics export with exemplar and no context and filtering observable instruments
  * Fix recursion error with sdk disabled and handler added to root logger
  * sdk: setup EventLogger when OTEL_PYTHON_LOGGING_AUTO_INSTRUMENTATION_ENABLED is set
  * api: fix logging of duplicate EventLogger setup warning
  * sdk: fix setting of process owner in ProcessResourceDetector
  * sdk: fix serialization of logs severity_number field to int
  * Remove `TestBase.assertEqualSpanInstrumentationInfo` method,
    use `assertEqualSpanInstrumentationScope` instead
  * sdk: instantiate lazily `ExemplarBucket`s in `ExemplarReservoir`s
  * semantic-conventions: Bump to 1.29.0
- from version 0.49b0
  * Removed superfluous py.typed markers and added them where they were missing
  * Include metric info in encoding exceptions
  * sdk: Add support for log formatting
  * sdk: Add Host resource detector
  * sdk: Implementation of exemplars
  * Implement events sdk
  * Update semantic conventions to version 1.28.0
  * Add support to protobuf 5+ and drop support to protobuf 3 and 4
  * Update environment variable descriptions to match signal
  * Record logger name as the instrumentation scope name
  * Fix memory leak in exporter and reader
  * Drop `OTEL_PYTHON_EXPERIMENTAL_DISABLE_PROMETHEUS_UNIT_NORMALIZATION` environment variable
  * Improve compatibility with other logging libraries that override
    `LogRecord.getMessage()` in order to customize message formatting
- Update BuildRequires and Requires from pyproject.toml
* Mon Sep  2 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.48b0
  * Implementation of Events API (#4054)
  * Make log sdk add `exception.message` to logRecord for exceptions whose argument
    is an exception not a string message (#4122)
  * Fix use of `link.attributes.dropped`, which may not exist (#4119)
  * Running mypy on SDK resources (#4053)
  * Added py.typed file to top-level module (#4084)
  * Drop Final annotation from Enum in semantic conventions (#4085)
  * Update log export example to not use root logger (#4090)
  * sdk: Add OS resource detector (#3992)
  * sdk: Accept non URL-encoded headers in `OTEL_EXPORTER_OTLP_*HEADERS`
    to match other languages SDKs (#4103)
  * Update semantic conventions to version 1.27.0 (#4104)
  * Add support to type bytes for OTLP AnyValue (#4128)
  * Export ExponentialHistogram and ExponentialHistogramDataPoint (#4134)
  * Implement Client Key and Certificate File Support for All OTLP Exporters (#4116)
  * Remove `_start_time_unix_nano` attribute from `_ViewInstrumentMatch` in favor
    of using `time_ns()` at the moment when the aggregation object is created (#4137)
- from version 0.47b0
  * Standardizing timeout calculation in measurement consumer collect to nanoseconds (#4074)
  * Optional scope attributes for logger creation (#4035)
  * Optional scope attribute for tracer creation (#4028)
  * OTLP exporter is encoding invalid span/trace IDs in the logs fix (#4006)
  * Update sdk process resource detector `process.command_args` attribute
    to also include the executable itself (#4032)
  * Fix `start_time_unix_nano` for delta collection for explicit bucket
    histogram aggregation (#4009)
  * Fix `start_time_unix_nano` for delta collection for sum aggregation (#4011)
  * Update opentracing and opencesus docs examples to not use JaegerExporter (#4023)
  * Do not execute Flask Tests in debug mode (#3956)
  * When encountering an error encoding metric attributes in the OTLP exporter,
    log the key that had an error. (#3838)
  * Fix `ExponentialHistogramAggregation` (#3978)
  * Log a warning when a `LogRecord` in `sdk/log` has dropped attributes
    due to reaching limits (#3946)
  * Fix RandomIdGenerator can generate invalid Span/Trace Ids (#3949)
  * Add Python 3.12 to tox (#3616)
  * Improve resource field structure for LogRecords (#3972)
  * Update Semantic Conventions code generation scripts:
    + Fix namespace exclusion that resulted in dropping  `os` and `net` namespaces.
    + Add `Final` decorator to constants to prevent collisions
    + Enable mypy and fix detected issues
    + Allow to drop specific attributes in preparation for Semantic Conventions v1.26.0 (#3973)
  * Update semantic conventions to version 1.26.0. (#3964)
  * Use semconv exception attributes for record exceptions in spans (#3979)
  * Fix _encode_events assumes events.attributes.dropped exists (#3965)
  * Validate links at span creation (#3991)
  * Add attributes field in  `MeterProvider.get_meter` and `InstrumentationScope` (#4015)
  * Fix inaccessible `SCHEMA_URL` constants in `opentelemetry-semantic-conventions` (#4069)
- from version 0.46b0
  * Fix class BoundedAttributes to have RLock rather than Lock (#3859)
  * Remove thread lock by loading RuntimeContext explicitly. (#3763)
  * Update proto version to v1.2.0 (#3844)
  * Add to_json method to ExponentialHistogram (#3780)
  * Bump mypy to 1.9.0 (#3795)
  * Fix exponential histograms (#3798)
  * Fix otlp exporter to export log_record.observed_timestamp (#3785)
  * Add capture the fully qualified type name for raised exceptions in spans (#3837)
  * Prometheus exporter sort label keys to prevent duplicate
    metrics when user input changes order (#3698)
  * Update semantic conventions to version 1.25.0.
    Refactor semantic-convention structure:
    + `SpanAttributes`, `ResourceAttributes`, and `MetricInstruments` are deprecated.
    + Attribute and metric definitions are now grouped by the namespace.
    + Stable attributes and metrics are moved to `opentelemetry.semconv.attributes`
    and `opentelemetry.semconv.metrics` modules.
    + Stable and experimental attributes and metrics are defined under
    `opentelemetry.semconv._incubating` import path. (#3586)
  * Rename test objects to avoid pytest warnings (#3823)
  * Add span flags to OTLP spans and links (#3881)
  * Record links with invalid SpanContext if either
    attributes or TraceState are not empty (#3917)
  * Add OpenTelemetry trove classifiers to PyPI packages (#3913)
  * Fix prometheus metric name and unit conversion (#3924)
    + This is a breaking change to prometheus metric names so they comply with the specification
    + You can temporarily opt-out of the unit normalization by setting the environment variable
    `OTEL_PYTHON_EXPERIMENTAL_DISABLE_PROMETHEUS_UNIT_NORMALIZATION=true`
    + Common unit abbreviations are converted to Prometheus conventions (`s` -> `seconds`),
    following the collector's implementation
    + Repeated `_` are replaced with a single `_`
    + Unit annotations (enclosed in curly braces like `{requests}`) are stripped away
    + Units with slash are converted e.g. `m/s` -> `meters_per_second`.
    + The exporter's API is not changed
  * Add parameters for Distros and configurators to configure autoinstrumentation
    in addition to existing environment variables. (#3864)
- from version 0.45b0
  * Make create_gauge non-abstract method (#3817)
  * Make `tracer.start_as_current_span()` decorator work with async functions (#3633)
  * Fix python 3.12 deprecation warning (#3751)
  * Bump mypy to 0.982 (#3776)
  * Add support for OTEL_SDK_DISABLED environment variable (#3648)
  * Fix ValueError message for PeriodicExportingMetricsReader (#3769)
  * Use `BaseException` instead of `Exception` in `record_exception` (#3354)
  * Make span.record_exception more robust (#3778)
  * Fix license field in pyproject.toml files (#3803)
- Update BuildRequires and Requires from pyproject.toml
* Sat Mar 23 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- update to 0.44b0:
  * Use Attribute rather than boundattribute in logrecord (#3567)
  * Fix flush error when no LoggerProvider configured for LoggingHandler (#3608)
  * Fix OTLPMetricExporter ignores preferred_aggregation property (#3603)
  * Logs: set observed_timestamp field (#3565)
  * Add missing Resource SchemaURL in OTLP exporters (#3652)
  * Fix loglevel warning text (#3566)
  * Prometheus Exporter string representation for target_info labels (#3659)
  * Logs: ObservedTimestamp field is missing in console exporter output (#3564)
  * Fix explicit bucket histogram aggregation (#3429)
  * Add code.lineno, code.function and code.filepath to all logs (#3645)
  * Add Synchronous Gauge instrument (#3462)
  * Drop support for 3.7 (#3668)
  * Include key in attribute sequence warning (#3639)
  * Upgrade markupsafe, Flask and related dependencies to dev and test
    environments (#3609)
  * Handle HTTP 2XX responses as successful in OTLP exporters (#3623)
  * Improve Resource Detector timeout messaging (#3645)
  * Add Proxy classes for logging (#3575)
  * Remove dependency on 'backoff' library (#3679)
* Thu Jan  4 2024 Dirk Müller <dmueller@suse.com>
- Initial package (0.43b0)
